@@ -736,9 +736,11 @@
 
 ) ; End Of (d-UploadRoutine)
 
+
+;;; play a note a mid-volume 80
 (define (PlayNote pitch duration)
-  (d-OutputMIDI (string-append "0x9$ " pitch " %%%"))
- (d-OneShotTimer duration (string-append "(d-OutputMIDI " "\"" "0x8$ " pitch " %%%" "\"" ")" )) 
+  (d-OutputMidiBytes (string-append "0x9$ " pitch " 80"))
+ (d-OneShotTimer duration (string-append "(d-OutputMidiBytes " "\"" "0x8$ " pitch " 0" "\"" ")" )) 
   )
 
 ;;;;;;;;;;;;;; Refresh Procedures.
@@ -841,16 +843,16 @@
     (if (boolean? (d-GetMidiOnTime))
 	(d-RecreateTimebase))
     (if (number? (d-GetMidiOnTime))
-	(d-SetPlaybackInterval (d-GetMidiOnTime) #t)
-	(d-RefreshDisplay))))
+	(begin (d-SetPlaybackInterval (d-GetMidiOnTime) #t)
+	(d-RefreshDisplay)))))
 
 (define (DenemoSetPlaybackEnd)
   (begin
     (if (boolean? (d-GetMidiOffTime))
 	(d-RecreateTimebase))
     (if (number? (d-GetMidiOffTime))
-	(d-SetPlaybackInterval #t (d-GetMidiOffTime))
-	(d-RefreshDisplay))))
+	(begin (d-SetPlaybackInterval #t (d-GetMidiOffTime))
+	(d-RefreshDisplay)))))
 
 (define (DenemoSetPlaybackIntervalToSelection)
   (begin
