@@ -25,6 +25,11 @@
 
 #define DENEMO_TEXTEDITOR_TAG "texteditor"
 
+/* values for is_grace attribute of CHORD type */
+#define GRACE_SECTION (1<<0) /*Note is in grace section */
+#define GRACED_NOTE (1<<1) /*Note has been individually designated a grace note */
+
+
 typedef void (*GActionCallback) (GtkAction *action, gpointer data);
 #define G_ACTIONCALLBACK(f) ((GActionCallback)(f)) 
  /* and the following typedefs are basically here for so that it's
@@ -158,6 +163,8 @@ typedef struct
   gint starttick; /**< When the object occurs */ 
   gint starttickofnextnote; /**< When the next object occurs */
   GList* midi_events;/**< data are the smf_event_ts that this object gives rise to */
+  gdouble earliest_time;/**< cached value of earliest time in midi_events, if no midi_events it holds time of preceding/following midi event   */
+  gdouble latest_time;/**< cached value of latest time in midi_events, if no midi_events it holds time of preceding/following midi event */
   /**< Allots extra space for accidentals or reverse-aligned notes if
    * the stem is down */
   gint space_before; /**< Used to specify how much space is needed before the object in display */
@@ -348,11 +355,13 @@ typedef struct DenemoPrefs
   gint system_height; /**< percent of display height per system  1-100 */
 
   gboolean playback_controls; /**< makes the playback controls visible */
+  gboolean midi_in_controls; /**< makes the midi in controls visible */
   gboolean articulation_palette; /**< makes the articulation pallete visible */
   gboolean notation_palette; /**< makes the Note/Rest entry toolbar visible */
   gboolean rhythm_palette; /**< makes the rhythm toolbar visable */
   gboolean object_palette;  /**< makes the object menu toolbar visible */
   gboolean console_pane;  /**< makes the console pane visible */
+  gboolean lyrics_pane;  /**< makes the lyrics pane visible */
 
   gboolean visible_directive_buttons; /**< This option makes the hbox containing score/movement directives visible */
 
@@ -509,6 +518,12 @@ typedef enum InputSource {
   INPUTMIDI
 } InputSource;
 
+typedef enum MidiDestination {
+  MIDITOSCORE = 0,
+  MIDITHRU = (1<<1),
+  MIDIRECORD = (1<<2),
+} MidiDestination;
+
 
 /**
  * Structure to contain the list of Instruments for the score
@@ -655,7 +670,9 @@ typedef struct DenemoScore
   gdouble start_time; /**< time in seconds to start playing at */
   gdouble end_time; /**< time to end playing at */
   DenemoObject *playingnow; /**< the last object played via MIDI; it must not be dereferenced as it may no longer exist */
+  gdouble playhead; /**< MIDI time in seconds of playhead, ie point when last MIDI event was processed for output */
   gdouble start_player;/**< system time when MIDI player started */
+  gpointer recorded_midi_track;//will be a GList * eventually for now an smf_track_t
   gdouble master_volume;/**< the volume (velocity) used is this times the nominal vol */
   gdouble master_tempo;/**< the tempo used is this times the nominal tempo */
   gdouble tempo_change_time;/**< system time from which the master_tempo is to be used */
@@ -788,6 +805,8 @@ typedef struct DenemoGUI
 
   GtkWidget* articulation_palette; /**< Articulation palette window */
   InputSource input_source;/**< Where pitches are coming into Denemo (keyboard, audio, midi) */
+  InputSource last_source;/**< Where the last input came from */
+  MidiDestination midi_destination;/**< Where MIDI in should go */
   input_mode mode; /**< Input mode for Score */
   GtkWidget *progressbar;
 
@@ -884,6 +903,7 @@ struct DenemoRoot
   GtkWidget *notebook;/**< contains the gui.page widgets */
   GtkWidget *statusbar;
   GtkWidget *playback_control;/**< frame containing controls for playback */
+  GtkWidget *midi_in_control;/**< frame containing controls for midi in */
   gint status_context_id;
   GtkWidget *input_source; /**< A label widget advising of source of external input */
   GString *input_filters; /**< Description of any filters operating on external input */
