@@ -1045,7 +1045,10 @@ insert_rhythm_pattern(DenemoGUI  *gui) {
 void
 insertion_point (DenemoScore * si)
 {
-  gtk_widget_draw(Denemo.gui->scorearea, NULL);//FIXME efficiency????
+  //gtk_widget_draw(Denemo.gui->scorearea, NULL);//FIXME efficiency????
+
+  scorearea_expose_event(NULL, NULL);
+
   gboolean next_measure;
 
   /* First, check to see if the insertion'll cause the cursor to
@@ -1113,10 +1116,6 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
   if ((mode & INPUTBLANK) || (gui->mode & INPUTBLANK) || (!rest &&(gui->mode&(INPUTRHYTHM))))
     mudela_obj_new->isinvisible = TRUE;
 
-  //  if (si->is_grace_mode)
-  //   ((chord *) mudela_obj_new->object)->is_grace = TRUE;
-
-
   /* Insert the new note into the score.  Note that while we may have
      added a measure above, object_insert will invoke nudgerightward,
      which will in turn invoke update_hscrollbar, so we
@@ -1137,9 +1136,11 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
 
 
   } else {
-    if(Denemo.gui->input_source==INPUTKEYBOARD) {
+    if(Denemo.gui->last_source==INPUTKEYBOARD) {
       DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
       playnotes (Denemo.prefs.immediateplayback, *(chord *) mudela_obj_new->object,  curstaffstruct->midi_channel);
+    } else {
+      Denemo.gui->last_source = INPUTKEYBOARD;
     }
   }
 }
@@ -1262,12 +1263,14 @@ notechange (DenemoScore * si, gboolean remove)
 	  g_free (curmudelaobj->user_string);
 	  curmudelaobj->user_string = NULL;
 	}
-      if(Denemo.gui->input_source==INPUTKEYBOARD) {
+      if(Denemo.gui->last_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
 	playnotes (Denemo.prefs.immediateplayback,
 	 *(chord *) curmudelaobj->object, curstaffstruct->midi_channel);
-      }
+      } else {
+      Denemo.gui->last_source = INPUTKEYBOARD;
+    }
     }
   return ret;
 }
@@ -1341,11 +1344,13 @@ incrementenshift (DenemoGUI * gui, gint direction)
 	  g_free (curmudelaobj->user_string);
 	  curmudelaobj->user_string = NULL;
 	}
-      if(Denemo.gui->input_source==INPUTKEYBOARD) {
+      if(Denemo.gui->last_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
 	playnotes (Denemo.prefs.immediateplayback,
 		   *(chord *) curmudelaobj->object, curstaffstruct->midi_channel);
+      } else {
+	Denemo.gui->last_source = INPUTKEYBOARD;
       }
       unre_data *data = (unre_data *) g_malloc (sizeof (unre_data));
       data->object = curmudelaobj;
@@ -1479,8 +1484,8 @@ dnm_insertmeasures (DenemoScore * si, gint number)
   si->cursor_appending = TRUE;
   si->currentobject = NULL;
   set_rightmeasurenum (si);
-  si->markstaffnum = 0;
-  calcmarkboundaries (si);
+  //si->markstaffnum = 0;
+  //calcmarkboundaries (si);
   /* update_hscrollbar (si); */
 }
 
@@ -1497,8 +1502,8 @@ insertmeasureafter (DenemoGUI *gui)
   si->cursor_appending = TRUE;
   si->currentobject = NULL;
   set_rightmeasurenum (si);
-  si->markstaffnum = 0;
-  calcmarkboundaries (si);
+  //si->markstaffnum = 0;
+  //calcmarkboundaries (si);
   /* update_hscrollbar (si); */
 }
 
@@ -1515,8 +1520,8 @@ addmeasureafter (DenemoGUI *gui)
   si->cursor_appending = TRUE;
   si->currentobject = NULL;
   set_rightmeasurenum (si);
-  si->markstaffnum = 0;
-  calcmarkboundaries (si);
+  //si->markstaffnum = 0;
+  // calcmarkboundaries (si);
   /* update_hscrollbar (si); */
 }
 
@@ -1534,7 +1539,8 @@ insertmeasurebefore (DenemoGUI *gui)
   si->currentobject = NULL;
   set_rightmeasurenum (si);
   si->markstaffnum = 0;
-  calcmarkboundaries (si);
+  if(si->markstaffnum)
+    calcmarkboundaries (si);
   /* update_hscrollbar (si); */
 }
 
@@ -1658,7 +1664,8 @@ void deletemeasureallstaffs(DenemoGUI * gui)
   si->currentmeasure =
     removemeasures (si, si->currentmeasurenum - 1, 1, TRUE);
   setcurrents (si);
-calcmarkboundaries (si);
+  if(si->markstaffnum)
+    calcmarkboundaries (si);
   score_status(gui, TRUE);
   si->markstaffnum = 0;
   isoffleftside (gui);
@@ -1685,7 +1692,8 @@ dnm_deletemeasure (DenemoScore * si)
    * the current measure to be the left of what's displayed */
 
   setcurrents (si);
-calcmarkboundaries (si);
+  if(si->markstaffnum)
+    calcmarkboundaries (si);
   si->markstaffnum = 0;
 
 
