@@ -34,7 +34,15 @@ measureleft (DenemoScriptParam *param);
 void
 measureright (DenemoScriptParam *param);
 
+void
+movetomeasureleft (DenemoScriptParam *param);
 
+void
+movetomeasureright (DenemoScriptParam *param);
+void
+movetostart (GtkAction *action, gpointer param);
+void
+movetoend (GtkAction *action, gpointer param);
 gboolean
 swapstaffs (GtkAction *action, gpointer param);
 gboolean
@@ -51,18 +59,36 @@ staffup (DenemoScriptParam *param);
 gboolean
 staffdown (DenemoScriptParam *param);
 
+gboolean
+movetostaffup (DenemoScriptParam *param);
+
+gboolean
+movetostaffdown (DenemoScriptParam *param);
+
 gboolean
 voiceup (DenemoScriptParam *param);
 
 gboolean
 voicedown (DenemoScriptParam *param);
 
-void
+gboolean
+movetovoiceup (DenemoScriptParam *param);
+
+gboolean
+movetovoicedown (DenemoScriptParam *param);
+
+gboolean
 cursorleft (DenemoScriptParam *param);
 
 gboolean
 cursorright (DenemoScriptParam *param);
 
+gboolean
+movecursorleft (DenemoScriptParam *param);
+
+gboolean
+movecursorright (DenemoScriptParam *param);
+
 void
 cursorup (DenemoScriptParam *param);
 
@@ -171,4 +197,7 @@ void
 insert_rhythm_pattern(DenemoGUI *gui);
 void
 toggle_tie (GtkAction *action, gpointer param);
+
+void
+dnm_inserttuplet (DenemoGUI * gui, tuplet_type type);
 #endif /*COMMANDFUNCSH */
