@@ -44,10 +44,9 @@ score_staffspace_change (GtkAction *action, gpointer callback_data);
 
 
 
-gboolean
-staff_properties_change (gpointer callback_data);
+
 void 
-staff_properties_change_cb (GtkAction * action, gpointer param);
+staff_properties_change_cb (GtkAction * action, DenemoScriptParam *param);
 
 
 
