@@ -128,6 +128,8 @@ struct infotopass
   gint startposition;//x coordinate where to start playing
   gint endposition;//x coordinate where to end playing
   gint playposition;//x coordinate of currently played music
+  gdouble leftmosttime;//MIDI time of left most object on last system line displayed
+  gdouble rightmosttime;//MIDI time of last object  displayed
 };
 
 /* count the number of syllables up to staff->leftmeasurenum */
@@ -196,32 +198,34 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
   DenemoScore *si = gui->si;
   DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
 
+
+  //this is the selection being given a blue background I guess
   //FIXME too much save and restore for trifling reasons...
-  if(itp->mark) {
+  if(Denemo.gui->si->playingnow==NULL && itp->mark) {
     cairo_save(cr);
     cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
     cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
     cairo_fill(cr);
     cairo_restore(cr);
   }
+  //g_print("%x %f %f %f\n", Denemo.gui->si->playingnow, Denemo.gui->si->playhead,  mudelaitem->earliest_time, mudelaitem->latest_time );
+  if( Denemo.gui->si->playingnow && (Denemo.gui->si->playhead > mudelaitem->earliest_time) && (Denemo.gui->si->playhead < mudelaitem->latest_time)) {
+    cairo_save(cr);
+    cairo_set_source_rgb( cr, 0.5, 1.0, 0.5 );
+    cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
+    cairo_fill(cr);
+    cairo_restore(cr);
+  }
 
 
 
 
 
-
-
-
-
-
-
-
-
   /* The current note, rest, etc. being painted */
   gint extra;
   if(mudelaitem == Denemo.gui->si->playingnow)
     itp->playposition = x + mudelaitem->x;
-  
+
   if(mudelaitem == itp->startobj)
     itp->startposition = x + mudelaitem->x +  mudelaitem->minpixelsalloted;
   if(mudelaitem == itp->endobj)
@@ -252,45 +256,22 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
     {
     case CHORD:
       { chord *thechord = ((chord *) mudelaitem->object);
-       if (thechord->is_figure && thechord->figure)
-      //if (thechord->is_figure)
-	//draw_figure (gui->pixmap, itp->gc,
-	//	     gtk_style_get_font (itp->widget->style),
-	//	     x + mudelaitem->x, y, mudelaitem);
-  
-	draw_figure ( cr,
-		     x + mudelaitem->x,
-		     y + (thechord->lowesty / 2),
-		     mudelaitem);
-  
-      else
-	{
-	  draw_chord ( cr, curobj, x + mudelaitem->x, y,
-		      GPOINTER_TO_INT (itp->mwidthiterator->data),
-		      itp->curaccs, itp->mark);
-	  if((thechord->highesty) < itp->highy)
- 	    itp->highy  = thechord->highesty/*, g_print("setting highy %d\n", itp->highy)*/;
-
-	  if((thechord->lowesty) > itp->lowy+STAFF_HEIGHT)
-	    itp->lowy  = thechord->lowesty-STAFF_HEIGHT;
-
-
-
-
-	}
-       if (thechord->is_fakechord)
-	draw_fakechord (cr,
-		     x + mudelaitem->x, 
-		     y - 45,
-		     //y - (thechord->highesty ), 
-		     mudelaitem);
-       else
-	{
-	  draw_chord ( cr, curobj, x + mudelaitem->x, y,
-		      GPOINTER_TO_INT (itp->mwidthiterator->data),
-		      itp->curaccs, itp->mark);
-	}
 
+	draw_chord ( cr, curobj, x + mudelaitem->x, y,
+		     GPOINTER_TO_INT (itp->mwidthiterator->data),
+		     itp->curaccs, itp->mark);
+	if((thechord->highesty) < itp->highy)
+	  itp->highy  = thechord->highesty/*, g_print("setting highy %d\n", itp->highy)*/;
+	
+	if((thechord->lowesty) > itp->lowy+STAFF_HEIGHT)
+	  itp->lowy  = thechord->lowesty-STAFF_HEIGHT;
+	
+	if (thechord->is_fakechord)
+	  draw_fakechord (cr,
+			  x + mudelaitem->x, 
+			  y - 45,
+			  mudelaitem);
+	
        if (si->currentstaffnum==itp->staffnum 
 	   && itp->verse && thechord->notes   
 	   && !itp->slur_stack
@@ -352,8 +333,8 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 			x + mudelaitem->x, y, 0);
 	}
 	/* notice the following does not check is_figure but checks if figure is not VOID) */      
-      if (!thechord->is_figure && thechord->figure)
-      //if (thechord->figure)
+      //if (!thechord->is_figure && thechord->figure)
+      if (thechord->figure)
         draw_figure (cr,
 		     x + mudelaitem->x,
 		     y + (thechord->lowesty / 2),
@@ -469,6 +450,7 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
   //  itp->line_end = itp->markx2 > (int)(gui->scorearea->allocation.width/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME));
 
 
+  itp->rightmosttime = mudelaitem->latest_time;
 
   //g_print("returning with %d\n", itp->highy);
   /* And give a return value and we're done */
@@ -582,13 +564,15 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
 
     
     if(itp->measurenum >= si->rightmeasurenum+1)
-      cairo_set_source_rgb( cr, 0.5,0.5,0.5 );//This draws light gray anything that may be only partially visible.
+	cairo_set_source_rgb( cr, 0.5,0.5,0.5 );//This draws light gray anything that may be only partially visible.
     else 
-      //  if(itp->mark)
-      //	cairo_set_source_rgb( cr, 0, 0, 1.0 );//blue
-      //  else
-	cairo_set_source_rgb( cr, 0, 0, 0 );//black;
-    extra_ticks = draw_object (cr, curobj, x, y, gui, itp);    
+      cairo_set_source_rgb( cr, 0, 0, 0 );//black;
+    extra_ticks = draw_object (cr, curobj, x, y, gui, itp);
+    {DenemoObject *obj = (DenemoObject *) curobj->data;
+      if(Denemo.gui->si->smf)
+	;//g_print("Latest %f earliest %f Obj type %d\n", obj->latest_time, obj->earliest_time, obj->type);
+    }
+    //itp->rightmosttime = curobj->latest_time;//we just want this for the rightmost object 
   }
   /* Paint the exclamation point, if necessary */
   cairo_save(cr);
@@ -718,7 +702,6 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   cairo_save(cr);
   /* Loop that will draw each measure. Basically a for loop, but was uglier
    * when written that way.  */
-
   itp->curmeasure =
     g_list_nth (thestaff->measures, itp->measurenum - 1);
   // g_print("measurenum %d\nx=%d\n", itp->measurenum, x);
@@ -729,6 +712,24 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   // g_print("Width is %d\n", itp->mwidthiterator->data);
 
   //itp->gc = gc;
+
+
+
+  {
+  //compute itp->leftmosttime here - the time at the start of this system
+  
+    objnode *curobj = (objnode *) itp->curmeasure->data;
+    if(curobj) {
+    DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
+    if(mudelaitem)
+      itp->leftmosttime = mudelaitem->earliest_time;
+    else
+      itp->leftmosttime = 1000000.0;
+    }
+    //g_print("Drawing staff %d leftmost time %f, measurenum %d\n",itp->staffnum, itp->leftmosttime, itp->measurenum);
+  }
+
+
   itp->line_end = FALSE;
   while ( (!itp->line_end)  //       itp->measurenum <= si->rightmeasurenum+1
 	 && itp->measurenum <= g_list_length (thestaff->measures))
@@ -740,7 +741,8 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 	  (int) (gui->scorearea->allocation.width/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME)))
 	if(itp->curmeasure->next) {
 	  itp->line_end=TRUE;
-	  //continue; continue is not good here, you cannot see things that Denemo thinks you can on the right.
+	  // if(Denemo.gui->si->playingnow)
+	  //	continue;//don't show grayed out measures while playing.
 	}
       
       draw_measure (cr, itp->curmeasure, x, y, gui, itp);
@@ -844,9 +846,9 @@ static void draw_playback_marker(cairo_t *cr, gint color, gint pos, gint yy, gin
 
 static void draw_playback_markers(cairo_t *cr, struct infotopass *itp, gint yy, gint line_height) {
 
-  if(itp->playposition>-1)
-    draw_playback_marker(cr, BLACK, itp->playposition, yy, line_height);
-  itp->playposition = -1;
+  //  if(itp->playposition>-1)
+  //   draw_playback_marker(cr, BLACK, itp->playposition, yy, line_height);
+  //  itp->playposition = -1;
   
   if(itp->startposition>0)
     draw_playback_marker(cr, GREEN, itp->startposition, yy, line_height);
@@ -857,7 +859,6 @@ static void draw_playback_markers(cairo_t *cr, struct infotopass *itp, gint yy,
   itp->endposition = -1;
 }
 
-
 /**
  * This actually draws the score, staff-by-staff 
  * @param widget pointer to the parent widget
@@ -873,7 +874,6 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
   gboolean repeat = FALSE;
   DenemoScore *si = gui->si;
   gint line_height = gui->scorearea->allocation.height*gui->si->system_height/gui->si->zoom;
-
   /* Initialize some fields in itp */
 
 
@@ -1004,33 +1004,69 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     // g_print("Drawn staffnum %d, at %d %s.\n", itp.staffnum,  y, itp.line_end?" another line":"End");
 
     if (itp.staffnum==si->top_staff)
-      print_system_separator (cr, line_height*system_num++);
-
+      print_system_separator (cr, line_height*system_num);
+    system_num++;
 
     // This block prints out continuations of the staff just printed
-    // we are going to have to store an x-count for each continuation so that mousing.c will know
-    // the correct value. LEFT_MARGIN only works for all same value notes...
     {
     int yy;
     yy = y + line_height;
     itp.left++;
     itp.right++;
-
+    if(Denemo.gui->si->playingnow && itp.measurenum >= si->rightmeasurenum)
+      itp.line_end = FALSE;//don't print whole lines of grayed out music during playback
 
     while(((itp.left-gui->lefts)<DENEMO_MAX_SYSTEMS-1) && itp.line_end && (yy<(gui->scorearea->allocation.height/gui->si->zoom))) {
       if (itp.staffnum==si->top_staff)
-	print_system_separator (cr, line_height*system_num++);
-
+	print_system_separator (cr, line_height*system_num);
+      system_num++;
       if(draw_staff (cr, curstaff, yy, gui, &itp))
 	repeat = TRUE;
-      draw_playback_markers(cr, &itp, yy, line_height);
-
-      // g_print("Drawn successively staffnum %d, at %d %s. Aloc %d,%d yy now %d line height %d\n", itp.staffnum,  yy, itp.line_end?" another line":"End", gui->scorearea->allocation.width, gui->scorearea->allocation.height, yy, line_height);
-     
+      draw_playback_markers(cr, &itp, yy, line_height);   
       yy += line_height;
       itp.left++;
       itp.right++;
+
+    } //end while printing out all the systems for this staff
+
+    //g_print("staff num %d measure %d playhead %f left time %f\nheight %d system_num %d\n", itp.staffnum,itp.measurenum, si->playhead, itp.leftmosttime, yy, system_num);
+    
+    si->rightmost_time = itp.rightmosttime;
+ 
+#if 1
+    if( (system_num>2) && Denemo.gui->si->playingnow && (si->playhead>itp.leftmosttime) && itp.measurenum <= g_list_length (((DenemoStaff*)curstaff->data)->measures)/*(itp.measurenum > (si->rightmeasurenum+1))*/) {
+
+      //put the next line of music at the top with a break marker
+   
+   
+      itp.left = &gui->lefts[0];
+      itp.right = &gui->rights[0];
+      
+      {
+	//clear the previously drawn version FIXME? do not draw in first place, will that be faster?
+	cairo_save(cr);
+	cairo_set_source_rgb( cr, 1.0, 1.0, 1.0 );
+
+	cairo_rectangle (cr, 0, y - (si->staffspace / 2) - ((DenemoStaff*)curstaff->data)->space_above, gui->scorearea->allocation.width/Denemo.gui->si->zoom, STAFF_HEIGHT+((DenemoStaff*)curstaff->data)->space_above + ((DenemoStaff*)curstaff->data)->space_below  + (si->staffspace));
+
+
+
+	cairo_fill(cr);
+	cairo_set_source_rgb( cr, 0.0, 0.0, 1.0 );//Strong Blue Line to break pages
+	cairo_rectangle (cr, 0, line_height-10, gui->scorearea->allocation.width/Denemo.gui->si->zoom, 10);
+	cairo_fill(cr);
+	cairo_restore(cr);
+      }
+      itp.line_end = FALSE;//to force print of timesig
+      if(itp.measurenum > (si->rightmeasurenum+1))
+	itp.measurenum = si->rightmeasurenum+1;
+      if(draw_staff (cr, curstaff, y, gui, &itp))
+	repeat = TRUE;  
+      // draw_playback_markers(cr, &itp, y, line_height);   
+      //draw_break_marker();
     }
+#endif
+
     }//end of block printing continuations
     *itp.left=0;//To signal end of valid systems
 
@@ -1046,9 +1082,9 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     curstaff = curstaff->next;
   }// for all the staffs
 
-
-  if(itp.last_midi)
-    si->rightmost_time = get_midi_off_time(itp.last_midi);
+  //g_print("Right most time %f\n", si->rightmost_time);
+  //  if(itp.last_midi)
+  //  si->rightmost_time = get_midi_off_time(itp.last_midi);
 
   return repeat;
 
@@ -1068,7 +1104,11 @@ DenemoGUI *gui = Denemo.gui;
    g_warning("Cannot draw!\n");
    return TRUE;
  }
-
+ if(widget==NULL) {
+   draw_score (NULL, gui);
+   return TRUE;
+ }
+  
  do{
    /* Clear the backing pixmap */
    if(Denemo.gui->input_source!=INPUTKEYBOARD && Denemo.gui->input_source!=INPUTMIDI &&
