@@ -939,7 +939,7 @@ static gchar *directive_get_midi_buffer(DenemoDirective *directive, gint *pnumby
   if(directive->midibytes) {
     gchar *bytes;
     bytes = substitute_midi_values(directive->midibytes->str, channel, volume);
-    g_print("Got %s as midi bytes\n", bytes);
+    //g_print("Got %s as midi bytes\n", bytes);
     char *next;
     char val;
     gint i, numbytes;
@@ -1204,9 +1204,10 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       track->user_pointer = (DevicePort *) device_manager_get_DevicePort(curstaffstruct->device_port->str); 
 
       /* The midi instrument */
-      event = midi_meta_text (4, curstaffstruct->midi_instrument->str);
-      smf_track_add_event_delta_pulses(track, event, 0);
-
+      if(curstaffstruct->midi_instrument && curstaffstruct->midi_instrument->len) {
+	event = midi_meta_text (4, curstaffstruct->midi_instrument->str);
+	smf_track_add_event_delta_pulses(track, event, 0);
+      }
       midi_channel = curstaffstruct->midi_channel;
       prognum = curstaffstruct->midi_prognum;
 
@@ -1336,6 +1337,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	      if(curobj->midi_events)
 		g_list_free(curobj->midi_events);//data belongs to libsmf
 	      curobj->midi_events = NULL;
+	      curobj->earliest_time = ticks_read*60.0/(cur_tempo*MIDI_RESOLUTION);//smf_get_length_seconds(smf);
+
+
 	/*******************************************
 	 *	huge switch:
 	 * 	here we handle every kind of object
@@ -1461,9 +1465,15 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  if (debug)
 		    fprintf (stderr, "duration is %s\n",
 			     fmt_ticks (duration));
-
+#else
+		  width = 0;
 #endif
 
+		  if (!chordval.notes) {
+		    //MUST GIVE OFF TIME FOR RESTS HERE
+		    curobj->latest_time = curobj->earliest_time + duration*60.0/(cur_tempo*MIDI_RESOLUTION);
+		    //g_print("rest of %f seconds at %f\n", duration/(double)MIDI_RESOLUTION, curobj->latest_time);
+		  }
 
 		  if (chordval.notes)
 		    {
@@ -1574,18 +1584,25 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      //g_print("event on %f\n", event->time_seconds);
 			      event->user_pointer = curobj;
 			      curobj->midi_events = g_list_append(curobj->midi_events, event);
+			      curobj->earliest_time = event->time_seconds;
+			      curobj->latest_time = curobj->earliest_time + duration*60.0/(cur_tempo*MIDI_RESOLUTION);
+
+
 #if DEBUG
 			      g_print("'%d len %d'", event->event_number, event->midi_buffer_length);
 			      //printf ("volume = %i\n", (mute_volume ? 0:mix));
 #endif
 			    }
 			  else if (slur_kill_p (note_status, n))
-			    {// FIXME what is this 12820??????
+			    {
 			      event = smf_event_new_from_bytes ( MIDI_NOTE_OFF | midi_channel, n, 0);
 			      //g_print("{%d}", event->event_number);
 			      smf_track_add_event_delta_pulses(track, event, mididelta);
 			      event->user_pointer = curobj;
 			      curobj->midi_events = g_list_append(curobj->midi_events, event);
+			      
+			      curobj->latest_time = event->time_seconds;
+			      curobj->earliest_time = curobj->latest_time - duration*60.0/(cur_tempo*MIDI_RESOLUTION);
 			      // g_print("event off lur kill %f\n", event->time_seconds);
 			    }
 			}
@@ -1630,10 +1647,15 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 				}
 			      /* write note off */
 			      event = smf_event_new_from_bytes ( MIDI_NOTE_OFF | midi_channel, n, 60);
+			      //g_print("smf length before %d %f mididelta %d",smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
 			      smf_track_add_event_delta_pulses(track, event, mididelta);
+			      //g_print("smf length after %d %f mididelta %d", smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
 			      event->user_pointer = curobj;
 			      curobj->midi_events = g_list_append(curobj->midi_events, event);
-			      //print("event off %f\n", event->time_seconds);
+			      curobj->latest_time = event->time_seconds;
+			      curobj->earliest_time = curobj->latest_time - duration*60.0/(cur_tempo*MIDI_RESOLUTION);
+			      //g_print("event off %f mididelta %d duration %d for curobj->type = %d\n", event->time_seconds, mididelta, duration, curobj->type);
+
 			    }
 			}
 		      /* end of second chord output loop */
@@ -1681,6 +1703,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  smf_track_add_event_delta_pulses(track, event, 0);
 		  event->user_pointer = curobj;
 		  curobj->midi_events = g_list_append(curobj->midi_events, event);
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;//= smf_get_length_seconds(smf);
 		  break;
 
 		case TUPOPEN:
@@ -1710,7 +1733,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		      break;
 		    }
 		  tuplet++;
-
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;//the last event
 		  break;
 		case TUPCLOSE:
 
@@ -1736,7 +1759,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		    case 0:
 		      break;
 		    }
-
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;//the last event
 		  break;
 
 		case DYNAMIC:
@@ -1748,6 +1771,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  cur_volume =
 		    string_to_vol (((dynamic *) curobj->object)->type->str,
 				   cur_volume);
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;//the last event
 		  break;
 
 		case KEYSIG:
@@ -1759,6 +1783,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  smf_track_add_event_delta_pulses(track, event, 0);
 		  event->user_pointer = curobj;
 		  curobj->midi_events = g_list_append(curobj->midi_events, event);
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;//= smf_get_length_seconds(smf);
 		  break;
 
 		case CLEF:
@@ -1805,6 +1830,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			break;
 		      }
 		  }
+		  curobj->earliest_time = curobj->latest_time  = event->time_seconds;// can be the last event
 		  break;
 		default:
 #if DEBUG
@@ -1812,7 +1838,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 #endif
 		  break;
 		}
-	    }
+	      
+	      //g_print("Object type  0x%x Starts at %f Finishes %f\n",curobj->type, curobj->earliest_time, curobj->latest_time);
+	    } // end of objects
 
       /*******************
        * Do some checking
@@ -1882,7 +1910,11 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
    ********/
   if(thefilename) {
     int dummy2;
+    if(Denemo.gui->si->recorded_midi_track)
+      smf_add_track(smf, Denemo.gui->si->recorded_midi_track);
     dummy2 = smf_save(smf, (const char*)thefilename);
+    if(Denemo.gui->si->recorded_midi_track)
+      smf_track_remove_from_smf(Denemo.gui->si->recorded_midi_track);
   }
   /* we are done */
 
