@@ -201,7 +201,7 @@ void fluid_playpitch(int key, int duration, int channel, int volume)
   /* Play a note */
   if (synth){
     //g_print("Emitting key %d\n", key);
-    fluid_synth_noteon(synth, channel, key, volume?volume:80);
+    fluid_synth_noteon(synth, channel, key, (volume?volume:127)*Denemo.gui->si->master_volume);
     g_timeout_add(duration, noteoff_callback, (gpointer)( (channel<<8) + key)); 
   }
 }
@@ -209,10 +209,45 @@ void fluid_playpitch(int key, int duration, int channel, int volume)
 void fluid_output_midi_event(unsigned char *buffer)
 {
   if (synth){
-    if ((buffer[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_ON)
-      fluid_synth_noteon(synth, buffer[0] & 0x0f, buffer[1], 80);
-    if ((buffer[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_OFF) 
-      fluid_synth_noteoff(synth, buffer[0] & 0x0f, buffer[1]);
+
+    gint chan = (buffer[0] & 0x0f);
+   
+    int success;
+    switch((buffer[0] & SYS_EXCLUSIVE_MESSAGE1))
+      {
+      case NOTE_ON: {
+	gint velocity =  ((gint)(Denemo.gui->si->master_volume * buffer[2]));
+	if(velocity>0x7F) velocity = 0x7F;
+	fluid_synth_noteon(synth, chan,  buffer[1], velocity);
+	//g_print("play %d on %f\n", chan, event->time_seconds);
+      }
+	break;
+       case NOTE_OFF:
+         fluid_synth_noteoff(synth, chan, buffer[1]);
+	 //g_print("play %d off %f\n", chan, event->time_seconds);
+	 break; 
+       case CONTROL_CHANGE:
+         fluid_synth_cc(synth, chan, buffer[1], buffer[2]);
+	 break; 
+                             
+       case PROGRAM_CHANGE:
+	 //g_print("changing on chan %d to prog? %d\n", chan,  event->midi_buffer[1]);
+         success = fluid_synth_program_change(synth, chan,  buffer[1]);
+	 //g_print("success = %d\n", success);
+	 break;
+ 
+	 //     case CHANNEL_PRESSURE:
+	 //return fluid_synth_channel_pressure(synth, chan,  event->midi_buffer[1]);
+ 
+       case PITCH_BEND:
+         fluid_synth_pitch_bend(synth, chan, buffer[1] + (buffer[2]<<8)
+				       /*I think! fluid_midi_event_get_pitch(event)*/);
+	 break;
+ 
+       case MIDI_SYSTEM_RESET:
+         fluid_synth_system_reset(synth);
+	 break;
+      }
   }
 }
 
@@ -259,6 +294,10 @@ static gboolean finish_play(gchar *callback) {
   if(callback && *callback)
     call_out_to_guile (callback);
   fluid_all_notes_off();
+  if(Denemo.gui->si->recorded_midi_track) {
+    safely_track_remove_from_smf(Denemo.gui->si->recorded_midi_track);
+    finish_recording();
+  }
   return FALSE;
 }
 
@@ -294,7 +333,7 @@ static gboolean fluidsynth_play_smf_event(gchar *callback)
   } 
   // g_print("rightmost %f event %f\n", si->rightmost_time, event->time_seconds);
   if(si->rightmost_time>0.0 && event->time_seconds>si->rightmost_time)
-     center_viewport();
+     page_viewport();
   gdouble thetime = get_time() - si->start_player;
   pause_time = thetime;
   //g_print("thetime %f\n", thetime);
@@ -305,6 +344,7 @@ static gboolean fluidsynth_play_smf_event(gchar *callback)
   if (thetime > event->time_seconds){
      event = smf_get_next_event(si->smf);
      si->playingnow = event->user_pointer;
+     si->playhead = event->time_seconds;//the time of the playhead used in draw.c
      //g_print("current object %p %x\n", event->user_pointer,((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1)) );
      if(((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1)==NOTE_ON) &&
 	event->time_seconds - last_draw_time>Denemo.prefs.display_refresh) {
@@ -325,9 +365,11 @@ static gboolean fluidsynth_play_smf_event(gchar *callback)
 	  fluid_synth_noteon(synth, chan,  event->midi_buffer[1], velocity);
 	//g_print("play %d on %f\n", chan, event->time_seconds);
       }
+	si->playhead += 0.001;//Make sure playhead is inside duration of note
 	break;
        case NOTE_OFF:
          fluid_synth_noteoff(synth, chan,  event->midi_buffer[1]);
+	 si->playhead -= 0.001;//Make sure playhead is inside duration of note
 	 //g_print("play %d off %f\n", chan, event->time_seconds);
 	 break; 
        case CONTROL_CHANGE:
@@ -370,6 +412,8 @@ void fluid_midi_play(gchar *callback)
     g_critical("Loading SMF failed.");
     return;
   }
+  if(gui->si->recorded_midi_track)
+    safely_add_track(gui->si->smf, gui->si->recorded_midi_track);
   static GString *callback_string;
 
   if(callback_string==NULL)
@@ -412,7 +456,6 @@ void fluid_midi_play(gchar *callback)
 void
 fluid_midi_stop(void)
 {
-
   if(playing_piece)
     toggle_playbutton();
   Denemo.gui->si->playingnow = NULL;
@@ -449,6 +492,16 @@ fluid_rhythm_feedback(gint duration, gboolean rest, gboolean dot) {
 
 static fluid_midi_driver_t* midi_in;
 
+static void handle_midi_event(gchar *buf) {
+  if(Denemo.gui->midi_destination & MIDIRECORD)
+    record_midi(buf,  get_time() - Denemo.gui->si->start_player);
+  if(Denemo.gui->midi_destination & MIDITHRU)
+    fluid_output_midi_event(buf);
+  else
+    process_midi_event(buf);
+}
+
+
 static void handle_midi_in(void* data, fluid_midi_event_t* event)
 {
   gchar buf[3];
@@ -473,7 +526,7 @@ static void handle_midi_in(void* data, fluid_midi_event_t* event)
 	buf[2]=128;
       }
       //g_print("key is %d\n", key);
-      process_midi_event(buf);
+      handle_midi_event(buf);
     }
     break;
 
@@ -486,7 +539,7 @@ static void handle_midi_in(void* data, fluid_midi_event_t* event)
       int key = fluid_midi_event_get_key(event);
       buf[0] = type;
       buf[1] = key;
-      process_midi_event(buf);
+      handle_midi_event(buf);
     }
     break;
   default:
@@ -533,5 +586,7 @@ void fluid_midi_play(void){}
 void fluid_midi_stop(void){}
 void fluid_midi_panic(void){}
 int fluid_kill_timer(void){}
+int fluid_stop_midi_in(void){}
+int fluid_start_midi_in(void){}
 #endif 
 
