@@ -52,6 +52,7 @@ NO WARRANTY; see the file COPYING for details."));
 /** 
  * Function to allow browsing the user manual
  * uses the given web browser to display the manual
+ * If param contains a url it opens that
  */
 void
 browse_manual (GtkAction * action, DenemoScriptParam *param)
@@ -70,6 +71,8 @@ browse_manual (GtkAction * action, DenemoScriptParam *param)
   gchar *browserpath = g_find_program_in_path (Denemo.prefs.browser->str);
   if (browserpath == NULL)
     {
+      if(run_file_association(manualuri))
+	return;
       /* show a warning dialog */
       GtkWidget *dialog =
         gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
