@@ -162,11 +162,15 @@ jack_playpitch(gint key, gint duration){
 #define MDC MD[client_number].ports[port_number]
 void 
 jack_output_midi_event(unsigned char *buffer, gint client_number, gint port_number){
+  DenemoScore *si = Denemo.gui->si;
+
   if (!jack_server_running)
     return; 
+  gint velocity = ((gint)(si->master_volume * buffer[2]));
+  if(velocity>0x7F) velocity = 0x7F;
   MDC.midi_buffer[ MDC.FillIndex].buffer[0] = buffer[0];
   MDC.midi_buffer[ MDC.FillIndex].buffer[1] = buffer[1];
-  MDC.midi_buffer[ MDC.FillIndex].buffer[2] = buffer[2];
+  MDC.midi_buffer[ MDC.FillIndex].buffer[2] = velocity;
   MDC.FillIndex++;
   if(MDC.FillIndex > DENEMO_BUFFER_MAX_INDEX) 
     MDC.FillIndex = 0;
@@ -244,7 +248,7 @@ static gboolean jackmidi_play_smf_event(gchar *callback)
   } 
   // g_print("rightmost %f event %f\n", si->rightmost_time, event->time_seconds);
   if(si->rightmost_time>0.0 && event->time_seconds>si->rightmost_time)
-     center_viewport();
+    page_viewport();
   gdouble thetime = get_time() - si->start_player;
   pause_time = thetime;
   //g_print("thetime %f\n", thetime);
@@ -255,7 +259,10 @@ static gboolean jackmidi_play_smf_event(gchar *callback)
   if (thetime > event->time_seconds){
      event = smf_get_next_event(si->smf);
      si->playingnow = event->user_pointer;
+     si->playhead = event->time_seconds;//the time of the playhead used in draw.c
      DP = event->track->user_pointer;
+     if (!DP)
+       return FALSE;
      //g_print("current object %p %x\n", event->user_pointer,((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1)) );
      if(((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1)==NOTE_ON) &&
 	event->time_seconds - last_draw_time>Denemo.prefs.display_refresh) {
@@ -267,8 +274,23 @@ static gboolean jackmidi_play_smf_event(gchar *callback)
     gint chan = (event->midi_buffer[0] & 0x0f);
     //g_print("message %x %x\n", event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1, PROGRAM_CHANGE);
     int success;
-    if (DP && (si->end_time - event->time_seconds > 0.01)) //Do not turn notes on too close to the end
-      jack_output_midi_event(event->midi_buffer, DP->device_number, DP->port_number);
+    switch((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1))
+    {
+      case NOTE_ON: {
+        if (si->end_time - event->time_seconds > 0.01) //Do not turn notes on too close to the end
+        jack_output_midi_event(event->midi_buffer, DP->device_number, DP->port_number);
+      }
+      si->playhead += 0.001;//Make sure playhead is inside duration of note
+      break;
+      case NOTE_OFF:
+        jack_output_midi_event(event->midi_buffer, DP->device_number, DP->port_number);
+	si->playhead -= 0.001;//Make sure playhead is inside duration of note
+	break;
+      default:
+	jack_output_midi_event(event->midi_buffer, DP->device_number, DP->port_number);
+	break;
+    }
+
   }
   return TRUE;
 }
@@ -478,24 +500,21 @@ remove_all_jack_midi_clients(){
 #endif
 }
 
+#define MDC MD[client_number].ports[port_number]
 int
 rename_jack_midi_port(int client_number, int port_number, char *port_name){
-#if 0
   int err = -1;
 
-  if (midi_device[client_number].output_ports[port_number] != NULL) //TODO is there a better way to check?
-    err = jack_port_set_name (midi_device[client_number].output_ports[port_number], port_name);
-  if (!err){
-    MD[client_number].port_names = g_list_nth(MD[client_number].port_names, port_number);
-    MD[client_number].port_names = g_string_new(port_name);
-    g_debug("Renamed JACK device %d output_ports[%d] to %s\n",client_number, port_number, port_name);
-  } else	  
+  if (MD[client_number].ports[port_number].port_name) 
+    err = jack_port_set_name (MDC.output_port, port_name);
+  if (!err)
+    MD[client_number].ports[port_number].port_name = g_string_new(port_name);
+  else	  
     g_critical("Could not rename JACK device %d output_ports[%d] to %s",client_number, port_number, port_name);
   
   return err;
-#endif
-  return -1;	
 }
+#undef MDC
 
 void 
 stop_jack(void){
