@@ -9,7 +9,7 @@
 int init_jack(void);
 int jackmidi(void);
 void  jackstop(void);
-void jack_midi_playback_start(void);
+void jack_midi_play(gchar *scheme_callback);
 void jack_midi_playback_stop(void);
 void jack_playpitch(gint key, gint duration);
 void jack_output_midi_event(unsigned char *buffer, gint client_number, gint port_number);
@@ -23,5 +23,6 @@ int rename_jack_midi_port(int client_number, int port_number, char *port_name);
 void remove_all_jack_midi_ports(gint client_number); 
 int maxnumber_of_clients(void);
 int maxnumber_of_ports(void);
-
+gboolean jackmidi_server_running(void);
+void jack_midi_panic();
 #endif //JACKMIDI_H
