@@ -112,6 +112,10 @@ instantiate_menus(gchar *menupath) {
   gchar *up1 = g_path_get_dirname(menupath);
   gchar *name=g_path_get_basename(menupath);
   GtkWidget *widget = gtk_ui_manager_get_widget(Denemo.ui_manager, up1);
+  if(!strcmp(up1, "/")) {
+    g_critical("bad menu path");
+    return;
+  }
   if(widget==NULL)
     instantiate_menus(up1);
   GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
@@ -563,6 +567,79 @@ load_xml_keymap (gchar * filename, gboolean interactive)
   xmlFreeDoc (doc);
   return ret;
 }
+
+
+
+
+
+gint
+load_xml_keybindings (gchar * filename)
+{
+  keymap *the_keymap = Denemo.map; 
+  gint ret = -1;
+  xmlDocPtr doc;
+  //xmlNsPtr ns;
+  xmlNodePtr rootElem;
+  if(filename==NULL)
+    return ret;
+  if(!g_file_test(filename, G_FILE_TEST_EXISTS))
+    return ret;
+  doc = xmlParseFile (filename);
+  if (doc == NULL) {
+    g_debug ("Could not read XML file %s", filename);
+    return ret;
+  }
+  rootElem = xmlDocGetRootElement (doc);
+  if (rootElem == NULL) {
+    g_warning ("Empty Document\n");
+    xmlFreeDoc (doc);
+    return ret;
+  }
+  //g_print ("RootElem %s\n", rootElem->name);
+  if (xmlStrcmp (rootElem->name, (const xmlChar *) "Denemo"))
+    {
+      g_warning ("Document has wrong type\n");
+      xmlFreeDoc (doc);
+      return ret;
+    }
+  rootElem = rootElem->xmlChildrenNode;
+
+  while (rootElem != NULL) {
+    if ( (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "merge"))) {
+      xmlNodePtr cur;
+      for (cur = rootElem->xmlChildrenNode; cur != NULL;  cur = cur->next) {
+	if (0 == xmlStrcmp (cur->name, (const xmlChar *) "map")) {
+	  parseBindings (doc, cur->xmlChildrenNode, Denemo.map);
+	  ret = 0;
+	}
+      }
+      update_all_labels(Denemo.map);
+    }
+    rootElem = rootElem->next;
+  }
+  xmlFreeDoc (doc);
+  return ret;
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 static void
