@@ -14,12 +14,6 @@
 #include "view.h"
 #include "commandfuncs.h"
 
-
-
-
-
-
-
 static GdkEventKey ** divert_key_event;/* Non null if key events are being intercepted by a function
 					* (which is running a gtk_mail_loop() for this reason).
 					* return TRUE if a key press successfully captured
@@ -129,7 +123,7 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
       execute_callback_from_name(the_keymap, command_name);
       gui = Denemo.gui;
       displayhelper (gui);
-      gtk_widget_draw (gui->scorearea, NULL);   
+      //gtk_widget_draw (gui->scorearea, NULL);//FIXME what is this doing here?   
       return TRUE;
     } else {
       g_warning("No action %i has no name", command_idx);
@@ -968,6 +962,18 @@ set_grace (DenemoGUI * gui)
   insertgrace (gui);
 }
 
+void
+toggle_grace (DenemoGUI * gui)
+{
+ DenemoObject *curmudelaobj = (DenemoObject *)
+    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
+ if(curmudelaobj && (curmudelaobj->type==CHORD)) {
+   ((chord *)curmudelaobj->object)->is_grace ^= GRACED_NOTE;
+   g_print("now %x\n",  ((chord *)curmudelaobj->object)->is_grace);
+ }
+}
+
+
 void
 force_cautionary (DenemoGUI * gui)
 {
