@@ -437,10 +437,11 @@ main (int argc, char *argv[])
   gchar *prefix = g_win32_get_package_installation_directory (NULL, NULL);
   gchar *guile = g_build_filename (prefix, "share", "guile", NULL);
   gchar *guile_1_8 = g_build_filename (guile, "1.8", NULL);
+  gchar *lilypond_current_scm = g_build_filename (prefix, "share", "lilypond", "current", "scm", NULL);
   if (g_file_test (guile, G_FILE_TEST_EXISTS))
     {
-      gchar *guile_path = g_strconcat (guile, ";", guile_1_8, NULL);
-      g_setenv ("GUILE_LOAD_PATH", guile_path, TRUE);
+      gchar *guile_path = g_strconcat (guile, ";", guile_1_8, ";", lilypond_current_scm, NULL);
+      g_setenv ("GUILE_LOAD_PATH", guile_path, TRUE);//FIXME TRUE means we overwrite any installed version of lilyponds scm, FALSE risks not putting denemos scm in the path...
       g_print ("Setting GUILE_LOAD_PATH=%s\n", guile_path);
     }
   else
@@ -465,12 +466,17 @@ main (int argc, char *argv[])
 
   gchar *program_files =  g_getenv("PROGRAMFILES");
   gchar *path = g_getenv ("PATH");
-  path = g_strconcat (path, ";", program_files, "/Windows Media Player", NULL);
-  path = g_strconcat (path, ";", program_files, "/Adobe/Reader 8.0/Reader", NULL);
-  path = g_strconcat (path, ";", program_files, "/Adobe/Reader 9.0/Reader", NULL);
-  g_setenv ("PATH", path, TRUE);
+  gchar *lilypond_path = g_build_filename(prefix, "bin", NULL);
+  gchar *lib_path = g_build_filename(prefix, "lib", NULL);
+  path = g_strconcat (path,";", lilypond_path, ";", lib_path, NULL);
 
+  g_setenv ("PATH", path, TRUE);
+  g_print("PATH set to %s\n", path);
+  gchar *lilypond_data_path = g_build_filename (prefix, "share", "lilypond", "current", NULL);
+  g_setenv ("LILYPOND_DATA_PATH", lilypond_data_path, FALSE);
+  g_print("LILYPOND_DATA_PATH will be %s if not already set", lilypond_data_path);
   gchar *fontpath = g_build_filename (prefix, "share", "fonts", "truetype","denemo", "fetta.ttf", NULL);
+  g_setenv ("LILYPOND_VERBOSE", "1", FALSE);
   add_font_directory(fontpath);
   fontpath = g_build_filename (prefix, "share", "fonts", "truetype","denemo", "denemo.ttf", NULL);
   add_font_directory(fontpath);
@@ -559,7 +565,7 @@ Report bugs to bug-denemo@gnu.org\n"), NULL) ;
 	  g_print("opt %c has %s\n", opts, argv[optind]);
       if (opts == 'h')
         {
-          g_print (helptext);
+          g_print ("%s", helptext);
           exit (0);
         }
       else if (opts == 's')
@@ -583,13 +589,13 @@ Report bugs to bug-denemo@gnu.org\n"), NULL) ;
         {
           g_print (_("\nGNU Denemo version "));
           g_print (VERSION ".\n\n");
-          g_print (copytext);
+          g_print ("%s", copytext);
           exit (0);
         }
     }
 
   g_print (_("\nGNU Denemo, a gtk+ frontend for GNU Lilypond\n"));
-  g_print (copytext);
+  g_print ("%s", copytext);
 
   g_free (helptext);
 
