@@ -285,15 +285,20 @@ settickvalsinmeasure (objnode * theobjs, gint ticksperbeat)
 		    }
 		  else if (in_grace)
 		    {
-		      ((chord *)theobj->object)->is_grace = TRUE;
-		      set_grace_numticks (theobj, 1/*8*/);/*8 =  sets durinticks too small */
-		      basic_ticks_in_grace_group += theobj->basic_durinticks;
+
+		      ((chord *)theobj->object)->is_grace |= GRACE_SECTION;//  means grace inside bracketed start/end markers
+
+		      theobj->durinticks = 0;
 		    }
 		  else
 		    {
-		      ((chord *)theobj->object)->is_grace = FALSE;
-		      set_tuplefied_numticks (theobj, 1, 1);//These two overwrite each other...
-		      set_grace_numticks (theobj, 1);
+
+		      ((chord *)theobj->object)->is_grace &= GRACED_NOTE;//leave any fixed grace, changed by toggle.
+		 
+		      if(((chord *)theobj->object)->is_grace)
+			theobj->durinticks = 0;
+		      else
+			theobj->durinticks =  theobj->basic_durinticks;
 		      ticks_so_far += theobj->durinticks;
 		    }
 		}
@@ -378,6 +383,10 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum,
       break;
     }
   theobj = (DenemoObject *) starter->data;
+
+  if (theobj->type == CHORD && (((chord *) theobj->object)->is_grace))
+    is_stemup = TRUE;
+
   if (is_stemup)
     stemoffset = MAX (beamgroup_lowest + 7, beamgroup_highest + 5);
   else
@@ -393,12 +402,16 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum,
       theobj = (DenemoObject *) curobjnode->data;
       if (theobj->type == CHORD)
 	{
-	  if (((chord *) theobj->object)->baseduration == 0)
+	  if ( (((chord *) theobj->object)->baseduration == 0))
 	    /* Whole notes are always laid out stemup */
 	    ((chord *) theobj->object)->is_stemup = TRUE;
 	  else
 	    {
-	      ((chord *) theobj->object)->is_stemup = is_stemup;
+	      if(((chord *) theobj->object)->is_grace)
+		((chord *) theobj->object)->is_stemup = TRUE;
+	      else
+		((chord *) theobj->object)->is_stemup = is_stemup;
+
 	      ((chord *) theobj->object)->stemy = stemy;
 	    }
 	  findreversealigns (theobj);
@@ -426,7 +439,7 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1,
   gint next_clef = *pclef;	/* Useful for when a clef intrudes
 				   mid-beamgroup */
   gint next_stem_directive = *stem_directive;
-  gboolean isrest;
+  gboolean isbeambreak;
 
 #ifdef DEBUG
   {static gint count = 0;
@@ -458,8 +471,8 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1,
   for (; curobjnode; prevobj = theobj, curobjnode = curobjnode->next)
     {
       theobj = (DenemoObject *) curobjnode->data;
-      isrest = (theobj->type == CHORD) && !((chord *) theobj->object)->notes;
-      if (theobj->type != CHORD || isrest)
+      isbeambreak = (theobj->type == CHORD) && (!((chord *) theobj->object)->notes || ((chord *) theobj->object)->is_grace);
+      if (theobj->type != CHORD || isbeambreak)
 	{
 	  /* A non-chord or rest always breaks up a beam group */
 	  /* LilyPond directives can have their own behaviour,
