@@ -180,12 +180,22 @@ gint get_midi_note(void) {
   return ret;
 }
 
+void safely_add_track(smf_t *smf, smf_track_t *track) {
+  if(track->smf==NULL)
+    smf_add_track(smf, track);
+}
+
+void safely_track_remove_from_smf(smf_track_t *track) {
+ if(track->smf!=NULL)
+   smf_track_remove_from_smf(track);
+}
 /**
  * enter_midi_note_in_score
  * @mid_c_offset enters the midi note steps above/below mid-c
  * @enshift enharmonic adjustment -1 is one flat etc.. 
  */
 static void enter_midi_note_in_score (DenemoGUI *gui, gint mid_c_offset, gint enshift, gint octave) {
+  gui->last_source = INPUTMIDI;
   gui->si->cursor_y = gui->si->staffletter_y = mid_c_offset;
   gui->si->cursor_y += 7*octave; 
   shiftcursor(gui, mid_c_offset);
@@ -200,6 +210,19 @@ typedef struct enharmonic
 }enharmonic;
 
 
+//Add the passed midi to a recording in Denemo.gui->si
+void record_midi(gchar *buf, gdouble time) {
+  smf_event_t *event = smf_event_new_from_pointer(buf, 3);
+  if(event && smf_event_is_valid(event)) {
+    if(Denemo.gui->si->recorded_midi_track && ((smf_track_t *)Denemo.gui->si->recorded_midi_track)->smf ) {
+      smf_track_add_event_seconds(Denemo.gui->si->recorded_midi_track, event, time);
+    } else {
+      smf_event_delete(event);
+      gdk_beep();
+    }
+  }
+}
+
 /* look for a new note played into midi input, if
    present insert it into the score */
 gint midientry(void) {
@@ -270,7 +293,11 @@ void process_midi_event(gchar *buf) {
     memcpy(divert_midi_event, buf, 3);//midi events are up to three bytes long
     gtk_main_quit();
     return;// not reached
-  } 
+  }
+  if(command==MIDI_NOTEON && velocity==0) {//Zero velocity NOTEON is used as NOTEOFF by some MIDI controllers
+    buf[0]=MIDI_NOTEOFF;
+    buf[2]=128;
+  }
   if(command==MIDI_NOTEON)
     store_midi_note(notenumber);
 }
@@ -324,15 +351,16 @@ process_callback (GIOChannel *source, GIOCondition condition, gchar * data)
 	buf[2]=128;
       }
       process_midi_event(buf);
-      return TRUE;//means do not remove event source
+      break;
     case MIDI_PGM_CHANGE:
     case MIDI_CHN_PRESSURE:
     case 0xF3:
       g_io_channel_read_chars (source, buf+1, 1, &bytes_read, &error);
-      return TRUE;
+      break;
     default:
-      return TRUE; 
+      break; 
     }
+  return TRUE; 
 }
 
 
@@ -370,11 +398,11 @@ gint stop_midi_input(void) {
     if(channel)
       g_io_channel_shutdown(channel, FALSE, &error);
     if(error)
-      g_warning(error->message);
+      g_warning("%s", error->message);
     else
-      channel = NULL;
-    return 0;
+      channel = NULL; 
   }
+return 0;
 }
 
 
