@@ -21,10 +21,14 @@ gint stop_pitch_input(void);
 void start_pitch_input(void);
 gboolean pitch_recognition_system_active(void);
 gboolean delete_tone(DenemoScore *si, chord *thechord);
+gboolean  apply_tones(DenemoScore *si);
 void clear_overlay(GtkAction *action, gpointer param);
 void store_pitch(double pitch);
 double get_pitch(void);
 void set_sharper (GtkAction *action, gpointer param);
 void set_flatter (GtkAction *action, gpointer param);
 gchar *determine_interval(gint bass, gint harmony);
+void signal_measure_end(void);
+gboolean pitch_entry_active(DenemoGUI *gui);
+GtkWidget *get_enharmonic_frame(void);
 #endif //PITCHENTRY_H
