@@ -142,12 +142,12 @@ goto_movement_staff_obj (DenemoGUI * gui, gint movementnum, gint staffnum, gint
   gtk_widget_hide(gui->si->buttonbox);
   gui->si = this->data;
   gtk_widget_show(gui->si->buttonbox);
-  if(!set_currentstaffnum (gui, staffnum))
+  if(!moveto_currentstaffnum (gui, staffnum))
     {
       warningdialog(_("No such voice"));
       return FALSE;
     }
-  if(!set_currentmeasurenum(gui, measurenum))
+  if(!moveto_currentmeasurenum(gui, measurenum))
   {
     warningdialog(_("No such measure"));
     return FALSE;
@@ -228,7 +228,8 @@ next_movement (GtkAction *action, DenemoScriptParam *param)
   gtk_widget_hide(gui->si->buttonbox);
   gui->si = this->data;
   gtk_widget_show(gui->si->buttonbox);
-  updatescoreinfo (gui);
+  set_master_tempo(gui->si, 1.0);
+  //!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
   set_rightmeasurenum (gui->si);
   find_leftmost_allcontexts (gui->si);
@@ -242,7 +243,7 @@ next_movement (GtkAction *action, DenemoScriptParam *param)
 }
 
 /**
- * Move to the next movement
+ * Move to the previous movement
  * @param action - Gtk Action event
  * @param gui - pointer to the DenemoGUI structure
  * @return none
@@ -265,8 +266,8 @@ prev_movement (GtkAction *action, DenemoScriptParam *param)
   gtk_widget_hide(gui->si->buttonbox);
   gui->si = this->data; 
   gtk_widget_show(gui->si->buttonbox);
-
-  updatescoreinfo (gui);
+  set_master_tempo(gui->si, 1.0);
+  //!!!!!!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
   set_rightmeasurenum (gui->si);
   set_bottom_staff (gui);
@@ -287,6 +288,7 @@ void
 init_score (DenemoScore * si, DenemoGUI *gui)
 {
   gchar *dir = (gchar*)locatedotdenemo ();
+
   si->readonly = 0;
   si->leftmeasurenum = si->rightmeasurenum = 1;
   si->top_staff = si->bottom_staff = 1;
@@ -301,6 +303,8 @@ init_score (DenemoScore * si, DenemoGUI *gui)
   si->cursor_y = 0;
   si->staffletter_y = 0;
   si->cursor_appending = TRUE;
+  si->zoom = Denemo.prefs.zoom>0?Denemo.prefs.zoom/100.0:1.0;
+  si->system_height = Denemo.prefs.system_height>0?Denemo.prefs.system_height/100.0:1.0;
 
   si->cursoroffend = FALSE;
   si->cursortime1=si->cursortime2=4;
@@ -315,7 +319,13 @@ init_score (DenemoScore * si, DenemoGUI *gui)
   si->start = 0;
   si->end = 0;
   si->stafftoplay = 0;
-
+  si->start_time = -1.0;
+  si->end_time = -1.0;//ie unset
+  set_master_volume(si, 1.0);//  si->master_volume=1.0;
+  
+ 
+  si->tempo_change_time=0.0;
+  set_master_tempo(si, 1.0);
   si->savebuffer = NULL;
   si->bookmarks = NULL;
 
