@@ -17,10 +17,14 @@ void free_score (DenemoGUI *gui);
 void next_movement (GtkAction *action, DenemoScriptParam *param);
 void prev_movement (GtkAction *action, DenemoScriptParam *param);
 void append_new_movement(GtkAction *action, gpointer param);
-void insert_movement_before (GtkAction *action, gpointer param);
-void insert_movement_after (GtkAction *action, gpointer param);
+void insert_movement_before (GtkAction *action, DenemoScriptParam *param);
+void insert_movement_after (GtkAction *action, DenemoScriptParam *param);
 void delete_movement (GtkAction *action, gpointer param);
 void movement_props_dialog (GtkAction *action, gpointer param);
 gboolean
 goto_movement_staff_obj (DenemoGUI * gui, gint movementnum, gint staffnum, gint measurenum, gint objnum);
+
+void PopPosition (GtkAction * action, DenemoScriptParam *param);
+void PushPosition (GtkAction * action, DenemoScriptParam *param);
+void PopPushPosition (GtkAction * action, DenemoScriptParam *param);
 #endif
