@@ -42,19 +42,18 @@ score_properties_dialog (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
 
-  GET_1PARAM(action, param, lilypond);
+  GET_1PARAM(action, param, fontsize);
  if(query) {
-   if( Denemo.gui->lilycontrol.lilypond == NULL) Denemo.gui->lilycontrol.lilypond = g_string_new(" ");
-   if(*query) if(!strcmp("lilypond", query))
-     g_string_assign(param->string, Denemo.gui->lilycontrol.lilypond->str);
-   param->status = TRUE;
+   if(*query) if(!strcmp("fontsize", query)) {
+     g_string_assign(param->string, Denemo.gui->lilycontrol.staffsize->str);
+     param->status = TRUE;
+   }
    return;
  }
-  if(lilypond) {
-    if(Denemo.gui->lilycontrol.lilypond)
-      g_string_assign(Denemo.gui->lilycontrol.lilypond, lilypond);
-    else
-      Denemo.gui->lilycontrol.lilypond = g_string_new(lilypond);
+ 
+  if(fontsize) {
+    g_string_assign(Denemo.gui->lilycontrol.staffsize, fontsize);
+    param->status = TRUE;
     return;
   }
 
@@ -72,7 +71,7 @@ score_properties_dialog (GtkAction *action, DenemoScriptParam *param)
   GtkWidget *measure_width;
   GtkWidget *staff_spacing;
   papersetupcb *cbdata = NULL;
-  headersetupcb *hsetup = NULL;
+
   DenemoScore *si = gui->si;
   g_assert (si != NULL);
 
@@ -91,8 +90,6 @@ score_properties_dialog (GtkAction *action, DenemoScriptParam *param)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), notebook, TRUE,
 		      TRUE, 0);
 
-  // Headers  
-  hsetup = headersetup (notebook, gui, TRUE);
 
   // Layout
   label = gtk_label_new_with_mnemonic (_("Display Layout"));
@@ -137,8 +134,7 @@ score_properties_dialog (GtkAction *action, DenemoScriptParam *param)
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
-      // Set headers
-      applyheader_settings(hsetup,gui);
+
 	/*
        if (!si->lily_file)
 	{
@@ -206,8 +202,8 @@ struct callbackdata
 
   GtkWidget *lilypond_before; 
   GtkWidget *lilypond_after;  
-  GtkWidget *layout;
-  GtkWidget *extra;  
+  // GtkWidget *layout;
+  // GtkWidget *extra;  
 };
 
 /**
@@ -217,28 +213,7 @@ struct callbackdata
 static void
 set_movement_props (gpointer data)
 {
-  struct callbackdata *cbdata = (struct callbackdata *) data;
-  DenemoGUI *gui = cbdata->gui;
-  DenemoScore *si = gui->si;
-#define ASSIGN(field) g_string_assign(si->headerinfo.field , (gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->field)));
-ASSIGN(title);	  
-ASSIGN(subtitle);	  
-ASSIGN(poet);	  
-ASSIGN(composer);	  
-ASSIGN(meter);	  
-ASSIGN(opus);	  
-ASSIGN(arranger);	  
-ASSIGN(instrument);	  
-ASSIGN(dedication);	  
-ASSIGN(piece);	  
-ASSIGN(head);	  
-ASSIGN(copyright);	  
-ASSIGN(footer);	  
-ASSIGN(tagline);	  
-ASSIGN(lilypond_before); 
-ASSIGN(lilypond_after);  
-ASSIGN(layout);
-ASSIGN(extra); 
+
 }
 
 
@@ -250,91 +225,5 @@ ASSIGN(extra);
 void
 movement_props_dialog (GtkAction *action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
 
-#if 0
-  GET_1PARAM(action, param, lilypond);
-  if(lilypond) {
-    if(Denemo.gui->lilycontrol.lilypond)
-      g_string_assign(Denemo.gui->lilycontrol.lilypond, lilypond);
-    else
-      Denemo.gui->lilycontrol.lilypond = g_string_new(lilypond);
-    return;
-  }
-#endif
-if(abandon_editprops_custom_scoreblock(gui))
-    return;
-
-  GtkWidget *dialog;
-  GtkWidget *label;
-  DenemoScore *si = gui->si;
-  static struct callbackdata cbdata;
-  cbdata.gui = gui;
-  dialog = gtk_dialog_new_with_buttons (_("Edit Properties of Movement"),
-					GTK_WINDOW (Denemo.window),
-					(GtkDialogFlags) (GTK_DIALOG_MODAL |
-							  GTK_DIALOG_DESTROY_WITH_PARENT),
-					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-					NULL);
-
-  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-
-
-GtkWidget *hpaned;
-GtkWidget *frame1;
-GtkWidget *frame2;
-  GtkWidget *entry;
-#define ACCESS(field) hpaned = gtk_hpaned_new ();\
-  frame1 = gtk_frame_new (NULL);\
-  frame2 = gtk_frame_new (NULL);\
-  gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_IN);\
-  gtk_frame_set_shadow_type (GTK_FRAME (frame2), GTK_SHADOW_IN);\
-  gtk_paned_pack1 (GTK_PANED (hpaned), frame1, FALSE, FALSE);\
-  gtk_paned_pack2 (GTK_PANED (hpaned), frame2, TRUE, FALSE);\
-  gtk_widget_set_size_request (frame1, 100, -1);\
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hpaned, TRUE, TRUE, 0);\
-  label = gtk_label_new (_(#field));\
-  gtk_container_add (GTK_CONTAINER (frame1), label);\
-  entry = gtk_entry_new ();\
-  cbdata.field = entry;\
-  if (si->headerinfo.field)\
-	gtk_entry_set_text (GTK_ENTRY (entry), si->headerinfo.field->str);\
-  gtk_container_add (GTK_CONTAINER (frame2), entry);\
-  gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-
-  ACCESS(title);	  
-  ACCESS(subtitle);	  
-  ACCESS(poet);	  
-  ACCESS(composer);	  
-  ACCESS(meter);	  
-  ACCESS(opus);	  
-  ACCESS(arranger);	  
-  ACCESS(instrument);	  
-  ACCESS(dedication);	  
-  ACCESS(piece);	  
-  ACCESS(head);	  
-  ACCESS(copyright);	  
-  ACCESS(footer);	  
-  ACCESS(tagline);	  
-
-  ACCESS(lilypond_before); 
-  ACCESS(lilypond_after);  
-  ACCESS(layout);
-  ACCESS(extra);  
-
-
-
-
-
-  /* gtk_widget_grab_focus (name); */
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
-  gtk_widget_show_all (dialog);
-
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
-    {
-      set_movement_props (&cbdata);
-    }
-  gtk_widget_destroy (dialog);
 }
