@@ -1,5 +1,4 @@
-/* view.h
- * Header file for functions for creating new views of 
+/* Header file for functions for creating new views of 
  * the main window
  * 
  *
@@ -91,4 +90,22 @@ load_local_scheme_init(void);
 
 void 
 execute_scheme(GtkAction *action, DenemoScriptParam *param);
+
+gchar
+modifier_code(gpointer fn);
+gboolean
+code_is_a_duration(gchar code);
+
+gint
+call_out_to_guile (const char *script);
+
+void 
+toggle_playbutton(void);
+
+void 
+set_master_volume(DenemoScore *si, gdouble volume);
+
+void 
+set_master_tempo(DenemoScore *si, gdouble tempo);
+
 #endif
